@@ -3,6 +3,20 @@
 from __future__ import unicode_literals
 from os.path import splitext
 
+from .rotunicode import RotUnicode
+
+
+_ROT_UNICODE = RotUnicode()
+
+
+def safe_unicode(data):
+    """ Helper to safely convert <string's> that contain unicode to unicode.
+    Otherwise argparse barfs. """
+    if isinstance(data, str):
+        return data.decode('utf-8')
+    else:
+        return unicode(data)
+
 
 def ruencode(string, extension=False):
     """Encode a string using 'rotunicode' codec.
@@ -30,7 +44,8 @@ def ruencode(string, extension=False):
     else:
         file_name, file_ext = splitext(string)
 
-    return file_name.encode('rotunicode') + file_ext
+    encoded_value, _ = _ROT_UNICODE.encode(file_name)
+    return encoded_value + file_ext
 
 
 def rudecode(string):
@@ -46,4 +61,5 @@ def rudecode(string):
     :rtype:
         `unicode`
     """
-    return string.decode('rotunicode')
+    decoded_value, _ = _ROT_UNICODE.decode(string)
+    return decoded_value
